==> ruby-jekyll-polyglot_1.5.0.orig.tar.gz: polyglot-1.5.0/site/_posts/2021-07-17-polyglot-1.5.0.md <==
---
layout: post
title: Polyglot 1.5.0
lang: en
---

Polyglot Release for version [version 1.5.0](https://rubygems.org/gems/jekyll-polyglot/versions/1.5.0), with new support for staggered builds by logical cpus.

## Faster Staggered Builds

This release modifies polyglot to start builds only after it confirms there is a cpu core ready to receive the build thread. This makes jekyll site builds run much faster on machines building more languages than with logical cpus ready to process the builds, preventing machine thrash and streamlining builds for large sites.

## Misc Updates

* Added Links to the github source code on every page on the site from the sidebar.
* Updated repo readme with new details about logical cpu usage.
* Polyglot continuous integration now provided by [CircleCI](https://circleci.com).
* Github user **musicmichaelc** created a jekyll theme with updates for use with [polyglot multilingual support](https://github.com/musicmichaelc/Type-on-Strap).

## Thanks

This release was made possible with the support of the following github users!
* [obfusk](https://github.com/obfusk)
* [eighthave](https://github.com/eighthave)
* [musicmichaelc](https://github.com/musicmichaelc)

## Want to help?

Has _Polyglot_ helped your website expand into new territories and markets?
Do you have a suggestion, contribution or bugfix you'd like to provide?
Want to see _this website_ translated into your native language?

Drop [me](https://github.com/untra) a line, open a [issues](https://github.com/untra/polyglot/issues) or make a [PR](https://github.com/untra/polyglot/pulls)! All support and contributions are greatly appreciated.

==> ruby-jekyll-polyglot_1.7.0.orig.tar.gz: polyglot-1.7.0/site/_posts/2021-07-17-polyglot-1.5.0.md <==
---
layout: post
title: Polyglot 1.5.0
lang: en
---

Polyglot Release for [version 1.5.0](https://rubygems.org/gems/jekyll-polyglot/versions/1.5.0), with new support for staggered builds by logical cpus.

## Faster Staggered Builds

This release modifies polyglot to start builds only after it confirms there is a cpu core ready to receive the build thread. This makes jekyll site builds run much faster on machines building more languages than with logical cpus ready to process the builds, preventing machine thrash and streamlining builds for large sites.

## Misc Updates

* Added Links to the github source code on every page on the site from the sidebar.
* Updated repo readme with new details about logical cpu usage.
* Polyglot continuous integration now provided by [CircleCI](https://circleci.com).
* Github user **musicmichaelc** created a jekyll theme with updates for use with [polyglot multilingual support](https://github.com/musicmichaelc/Type-on-Strap).

## Thanks

This release was made possible with the support of the following github users!
* [obfusk](https://github.com/obfusk)
* [eighthave](https://github.com/eighthave)
* [musicmichaelc](https://github.com/musicmichaelc)

## Want to help?

Has _Polyglot_ helped your website expand into new territories and markets?
Do you have a suggestion, contribution or bugfix you'd like to provide?
Want to see _this website_ translated into your native language?

Drop [me](https://github.com/untra) a line, open a [issues](https://github.com/untra/polyglot/issues) or make a [PR](https://github.com/untra/polyglot/pulls)! All support and contributions are greatly appreciated.
